Questions about Parallel Worlds by Michio Kaku: the big bang | Physics Forums - The Fusion of Science and Community
Description: Hi, I've bought PW recently and began reading it just yesterday. I have felt some doubts while reading it, since I haven't had any physics since I left...

- Forums
  - Search Forums
  - Recent Posts
  - Unanswered Threads
- Videos
  - Search Media
  - New Media
- Members
  - Notable Members
  - Current Visitors
  - Recent Activity
  - New Profile Posts
- Insights
- Search

### Log in or Sign up

1. Limited time only! Sign up for a free 30min personal tutor trial with Chegg Tutors
   Dismiss Notice

Dismiss Notice
Join Physics Forums Today!
The friendliest, high quality science and math community on the planet! Everyone who loves science is here!

# Questions about Parallel Worlds by Michio Kaku: the big bang

1. Jun 9, 2012 #1

   ### ail

   ###

   > Hi, I've bought PW recently and began reading it just yesterday. I have felt some doubts while reading it, since I haven't had any physics since I left high school and that has been a long time ago. Also, all this astrophysics always a tad mind-boggling to me. So far I have 2 sets of questions (but I'm onlin in the 2nd chapter now)
   > 1)
   > In the book, Michio Kaku says the universe expanded at a rate faster than light, but that this does not contradict the limit on light's velocity because it was the empty space that was expanding, not an object that was moving. I'm sorry, but I don't understand this. How is it that the empty space is expanding? Are we saying that the objects in it are fixed but that they being pushed by an ever growing sort of tissue between them, that happens to be "empty space"? If it is not this, how can we argue that the objects are not moving, and that they are not moving beyond the speed of light although they're expanding faster than that?
   > 2)
   > MK also says at another point that we now have a device that photographed objects 13 x10^9 light-years away (I prefer using scientific notation since 'billion' is a highly ambiguous term depending on where you're from). That means that we have just now captured the light of an object as it existed that time ago. I understand the basic idea but I can't visualize it very well. So, in the big bang, there is a fixed point in space and time (let's call it t=0) and then everything starts expanding from then. Eventually, our own location expands to. First, does this mean the universe is some kind of sphere or ellipsoid that expands radially from a center? But then, some objects must travel faster than others, right? why do they travel at different speeds? Ok, so Earth has not appeared at the time of the big bang, but some thousand million years after. When it forms, it is already a fair distance away from the origin point of the big bang, let's say the centre of the sphere. Then when we captured this light, were we looking in the direction of the center of the universe, say, towards the opposite direction that our galaxy is travelling in? And does that mean that whatever light was caused by that explosion is still there, stopped in place? But shouldn't have light travelled too? And if it did, then is it truly "behind" us? Shouldn't it have sped away ahead of the objects that were meanwhile expelled?
   > I'm sorry if this is disorganized, but I have real difficulty around these concepts. Perhaps some animation of this expansion of the universe would be useful, if someone knows where I can find it.
   > Thanks if any of you can help me in here.

   ail, Jun 9, 2012
2. Phys.org - latest science and technology news stories on Phys.org
   - • Electromagnetic water cloak eliminates drag and wake
   - • Glass with switchable opacity could improve solar cells and LEDs
   - • A diamond as the steppingstone to new materials, using plasma physics technology
3. Jun 9, 2012 #2

   ### Ken G

   Gold Member

   ###

   > The very first thing you need to do is get rid of this picture that the Big Bang "happened at a point". The Big Bang is not a model of a happening, it is a model of an evolutionary process, whose origin we know very little about and it's best not even to include the origin in the evolutionary model. The evolutionary process looks like very hot, very dense material and fields, which is everywhere expanding and so getting less dense and less hot with age. It is "how the universe ages", that's the Big Bang model. Currently this model says very little, or even nothing, about the spatial extent of this hot dense material and fields, we only get to see a piece of it so we don't know how far it extends. It was never "a point", our ability to do physics breaks down long before we could ever accurately describe it as that.
   > So get rid of the "singular point" idea, that single picture causes so many misconceptions about the Big Bang I wish no one had ever mentioned it anywhere (yet it seems to be the single thing that almost everyone hears!). Instead, take a 2 dimensional replacement of 3d space (it's easier to picture and talk about), and just imagine you have a rubber chess board. The squares on the board are small, and the tiny pieces on those squares are packed in very tightly. This is some arbitrary point in the expansion process, it's not the "very beginning" because there is no such point in the Big Bang model-- we just start it whereever we have some observational constraints on it, be they direct or inferred, but noting that if they are inferred, they require that we have some description of the physics (and that's what we don't have if it's a "point"). Now imagine stretching the rubber board, leaving all the pieces in the same squares (and the pieces don't stretch, their size is determined by their own internal physics). Finally, imagine that ants are crawling around on the board in straight lines from piece to piece.
   > In this analogy, the pieces are galaxy clusters, the ants are photons, and the board is "space itself." Please note that we do not have any current physical model of space, so this is just a picture, and it works with respect to general relativity in a particularly common choice of spatial coordinate (the one where the location of the pieces stays fixed, to it's the choice that corresponds to squares on the expanding chessboard). So nothing is "moving faster than light", because nothing is moving at all except the ants, and they are crawling across the board at speed c. However, the rate of change of distance between pieces on the board can indeed be > c, if the pieces are far enough away from each other (this is the Hubble law).
   > The density of pieces obviously drops, the next thing to get is that the light (ants) will be observed to redshift by the factor that equals the factor by which the chess board has stretched from the age they were emitted to the age they were observed. We say their wavelength "expands with space" to picture this factor increase in wavelength. But the key point to remember is that the photons we get from far far away are from someplace that was always a distance away from our "square", it was just not as far then as it is now. Another point to get is that ants crawling at c can get between two points on a rubber expanding chessboard even if the square they left from has its distance increasing at a rate greater than c-- that's just as true for ants as it is for light.

   Ken G, Jun 9, 2012
4. Jun 9, 2012 #3

   ### phinds

   Insights Author
   Gold Member
   2016 Award

   ###

   > ail said: ↑

   > > 1)
   > > In the book, Michio Kaku says the universe expanded at a rate faster than light, but that this does not contradict the limit on light's velocity because it was the empty space that was expanding, not an object that was moving. I'm sorry, but I don't understand this. How is it that the empty space is expanding? Are we saying that the objects in it are fixed but that they being pushed by an ever growing sort of tissue between them, that happens to be "empty space"? If it is not this, how can we argue that the objects are not moving, and that they are not moving beyond the speed of light although they're expanding faster than that?

   > I like to use the terms "moving THROUGH space" and "moving WITH space", although I have had some push-back from other members here, pointing out that this is pretty ambiguous terminology. Moving THROUGH space is subject to the cosmic speed limit c, but moving WITH space is not. It's like a boat moving 10MPH down a raging river that is moving 30MPH. The boat's motor is subject to a 10MPH speed liimit, but a person on the shore sees the boat moving 40MPH.
   > Try this:
   > www.phinds.com/balloonanalogy
   > I think it will help with a lot of your questions.

   phinds, Jun 9, 2012

Show Ignored Content
Know someone interested in this topic? Share this thread via Reddit, Google+, Twitter, or Facebook
A First Idea of Quantum Field Theory – 20 Part Series
A Journey to The Manifold SU(2) – Part I
New Research on Untying Knots in Polymers
How I Stopped Worrying and Learned to Love Orthodox Quantum Mechanics
Using the Spaghetti-Twist to Align DNA
Mathematical Quantum Field Theory – Gauge Symmetries
10 Math Tips to Save Time and Avoid Mistakes
Intransitive Dice with a Twist
Further Sums Found Through Fourier Series
Mathematical Quantum Field Theory – Phase Space
Super p-Brane Theory Emerging from Super Homotopy Theory

  Similar Discussions: Questions about Parallel Worlds by Michio Kaku: the big bang

1. ### Parallel Worlds by Michio Kaku (Replies: 9)

2. ### Michio Kaku, Parallel Universes, and Galactic EZ Bake Ovens (Replies: 2)

3. ### Question about Big Bang Theory (Replies: 3)

4. ### Michio Kaku (Replies: 4)

5. ### Can someone explain what Michio Kaku is talking about in this video? (Replies: 15)

Loading...

- Log in with Facebook
- Log in with Twitter

Your name or email address:

Do you already have an account?
  - No, create an account now.
  - Yes, my password is:
  - Forgot your password?

  Stay logged in